package com.qianhe.system.controller;

import com.qianhe.common.annotation.Log;
import com.qianhe.common.core.controller.BaseController;
import com.qianhe.common.core.domain.AjaxResult;
import com.qianhe.common.core.page.TableDataInfo;
import com.qianhe.common.enums.BusinessType;
import com.qianhe.common.utils.poi.ExcelUtil;
import com.qianhe.system.domain.WaterStation;
import com.qianhe.system.service.IWaterStationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 站点Controller
 *
 * @author qianhe
 * @date 2023-11-23
 */
@RestController
@RequestMapping("/system/station")
public class WaterStationController extends BaseController
{
    @Autowired
    private IWaterStationService waterStationService;

    /**
     * 查询站点列表
     */
    @PreAuthorize("@ss.hasPermi('system:station:list')")
    @GetMapping("/list")
    public TableDataInfo list(WaterStation waterStation)
    {
        startPage();
        List<WaterStation> list = waterStationService.selectWaterStationList(waterStation);
        return getDataTable(list);
    }

    /**
     * 导出站点列表
     */
    @PreAuthorize("@ss.hasPermi('system:station:export')")
    @Log(title = "站点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WaterStation waterStation)
    {
        List<WaterStation> list = waterStationService.selectWaterStationList(waterStation);
        ExcelUtil<WaterStation> util = new ExcelUtil<WaterStation>(WaterStation.class);
        util.exportExcel(response, list, "站点数据");
    }

    /**
     * 获取站点详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:station:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(waterStationService.selectWaterStationById(id));
    }

    /**
     * 新增站点
     */
    @PreAuthorize("@ss.hasPermi('system:station:add')")
    @Log(title = "站点", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WaterStation waterStation)
    {
        return toAjax(waterStationService.insertWaterStation(waterStation));
    }

    /**
     * 修改站点
     */
    @PreAuthorize("@ss.hasPermi('system:station:edit')")
    @Log(title = "站点", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WaterStation waterStation)
    {
        return toAjax(waterStationService.updateWaterStation(waterStation));
    }

    /**
     * 删除站点
     */
    @PreAuthorize("@ss.hasPermi('system:station:remove')")
    @Log(title = "站点", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(waterStationService.deleteWaterStationByIds(ids));
    }
}
