package com.qianhe.system.service.impl;

import com.qianhe.common.utils.DateUtils;
import com.qianhe.system.domain.WaterStation;
import com.qianhe.system.mapper.WaterStationMapper;
import com.qianhe.system.service.IWaterStationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 站点Service业务层处理
 *
 * @author qianhe
 * @date 2023-11-23
 */
@Service
public class WaterStationServiceImpl implements IWaterStationService
{
    @Autowired
    private WaterStationMapper waterStationMapper;

    /**
     * 查询站点
     *
     * @param id 站点主键
     * @return 站点
     */
    @Override
    public WaterStation selectWaterStationById(Long id)
    {
        return waterStationMapper.selectWaterStationById(id);
    }

    /**
     * 查询站点列表
     *
     * @param waterStation 站点
     * @return 站点
     */
    @Override
    public List<WaterStation> selectWaterStationList(WaterStation waterStation)
    {
        return waterStationMapper.selectWaterStationList(waterStation);
    }

    /**
     * 新增站点
     *
     * @param waterStation 站点
     * @return 结果
     */
    @Override
    public int insertWaterStation(WaterStation waterStation)
    {
        waterStation.setCreateTime(DateUtils.getNowDate());
        return waterStationMapper.insertWaterStation(waterStation);
    }

    /**
     * 修改站点
     *
     * @param waterStation 站点
     * @return 结果
     */
    @Override
    public int updateWaterStation(WaterStation waterStation)
    {
        return waterStationMapper.updateWaterStation(waterStation);
    }

    /**
     * 批量删除站点
     *
     * @param ids 需要删除的站点主键
     * @return 结果
     */
    @Override
    public int deleteWaterStationByIds(Long[] ids)
    {
        return waterStationMapper.deleteWaterStationByIds(ids);
    }

    /**
     * 删除站点信息
     *
     * @param id 站点主键
     * @return 结果
     */
    @Override
    public int deleteWaterStationById(Long id)
    {
        return waterStationMapper.deleteWaterStationById(id);
    }
}
