package com.qianhe.system.service.impl;

import com.qianhe.common.utils.DateUtils;
import com.qianhe.system.domain.WaterUser;
import com.qianhe.system.mapper.WaterUserMapper;
import com.qianhe.system.service.IWaterUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户Service业务层处理
 *
 * @author qianhe
 * @date 2023-11-23
 */
@Service
public class WaterUserServiceImpl implements IWaterUserService
{
    @Autowired
    private WaterUserMapper waterUserMapper;

    /**
     * 查询用户
     *
     * @param id 用户主键
     * @return 用户
     */
    @Override
    public WaterUser selectWaterUserById(Long id)
    {
        return waterUserMapper.selectWaterUserById(id);
    }

    /**
     * 查询用户列表
     *
     * @param waterUser 用户
     * @return 用户
     */
    @Override
    public List<WaterUser> selectWaterUserList(WaterUser waterUser)
    {
        return waterUserMapper.selectWaterUserList(waterUser);
    }

    /**
     * 新增用户
     *
     * @param waterUser 用户
     * @return 结果
     */
    @Override
    public int insertWaterUser(WaterUser waterUser)
    {
        waterUser.setCreateTime(DateUtils.getNowDate());
        return waterUserMapper.insertWaterUser(waterUser);
    }

    /**
     * 修改用户
     *
     * @param waterUser 用户
     * @return 结果
     */
    @Override
    public int updateWaterUser(WaterUser waterUser)
    {
        return waterUserMapper.updateWaterUser(waterUser);
    }

    /**
     * 批量删除用户
     *
     * @param ids 需要删除的用户主键
     * @return 结果
     */
    @Override
    public int deleteWaterUserByIds(Long[] ids)
    {
        return waterUserMapper.deleteWaterUserByIds(ids);
    }

    /**
     * 删除用户信息
     *
     * @param id 用户主键
     * @return 结果
     */
    @Override
    public int deleteWaterUserById(Long id)
    {
        return waterUserMapper.deleteWaterUserById(id);
    }
}
